# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: steammessages_friendmessages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import service as _service
from google.protobuf import service_reflection
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import steam.protobufs.steammessages_base_pb2 as steammessages__base__pb2
import steam.protobufs.steammessages_unified_base_pb2 as steammessages__unified__base__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='steammessages_friendmessages.proto',
  package='',
  syntax='proto2',
  serialized_options=b'\220\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"steammessages_friendmessages.proto\x1a\x18steammessages_base.proto\x1a steammessages_unified_base.proto\"\xf1\x05\n)CFriendMessages_GetRecentMessages_Request\x12\x10\n\x08steamid1\x18\x01 \x01(\x06\x12\x10\n\x08steamid2\x18\x02 \x01(\x06\x12L\n\x05\x63ount\x18\x03 \x01(\rB=\x82\xb5\x18\x39If non-zero, cap the number of recent messages to return.\x12s\n\x18most_recent_conversation\x18\x04 \x01(\x08\x42Q\x82\xb5\x18MGrab the block of chat from the most recent conversation (a ~5 minute period)\x12\xa9\x01\n\x12rtime32_start_time\x18\x05 \x01(\x07\x42\x8c\x01\x82\xb5\x18\x87\x01If non-zero, return only messages with timestamps greater or equal to this. If zero, we only return messages from a recent time cutoff.\x12\x45\n\rbbcode_format\x18\x06 \x01(\x08\x42.\x82\xb5\x18*Return the results with bbcode formatting.\x12\x84\x01\n\rstart_ordinal\x18\x07 \x01(\rBm\x82\xb5\x18iCombined with start time, only messages after this ordinal are returned (dedupes messages in same second)\x12M\n\ttime_last\x18\x08 \x01(\rB:\x82\xb5\x18\x36if present/non-zero, return only messages before this.\x12\x14\n\x0cordinal_last\x18\t \x01(\r\"\x82\x04\n*CFriendMessages_GetRecentMessages_Response\x12~\n\x08messages\x18\x01 \x03(\x0b\x32\x39.CFriendMessages_GetRecentMessages_Response.FriendMessageB1\x82\xb5\x18-Array of messages, returned newest to oldest.\x12\x16\n\x0emore_available\x18\x04 \x01(\x08\x1a\xbb\x02\n\rFriendMessage\x12\x11\n\taccountid\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0f\n\x07ordinal\x18\x04 \x01(\r\x12\\\n\treactions\x18\x05 \x03(\x0b\x32I.CFriendMessages_GetRecentMessages_Response.FriendMessage.MessageReaction\x1a\x83\x01\n\x0fMessageReaction\x12L\n\rreaction_type\x18\x01 \x01(\x0e\x32\x15.EMessageReactionType:\x1ek_EMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x02 \x01(\t\x12\x10\n\x08reactors\x18\x03 \x03(\r\"\xdf\x02\n1CFriendsMessages_GetActiveMessageSessions_Request\x12\x7f\n\x11lastmessage_since\x18\x01 \x01(\rBd\x82\xb5\x18`return only session information where a chat message has been sent since this time (for polling)\x12\xa8\x01\n\x1bonly_sessions_with_messages\x18\x02 \x01(\x08\x42\x82\x01\x82\xb5\x18~If non-zero, return only message sessions that have messages since our message cutoff. If zero, we return all active sessions.\"\xfc\x02\n2CFriendsMessages_GetActiveMessageSessions_Response\x12\x62\n\x10message_sessions\x18\x01 \x03(\x0b\x32H.CFriendsMessages_GetActiveMessageSessions_Response.FriendMessageSession\x12i\n\ttimestamp\x18\x02 \x01(\rBV\x82\xb5\x18RThis should be passed in the next request as lastmessage_since to poll for updates\x1aw\n\x14\x46riendMessageSession\x12\x18\n\x10\x61\x63\x63ountid_friend\x18\x01 \x01(\r\x12\x14\n\x0clast_message\x18\x02 \x01(\r\x12\x11\n\tlast_view\x18\x03 \x01(\r\x12\x1c\n\x14unread_message_count\x18\x04 \x01(\r\"\xc2\x01\n#CFriendMessages_SendMessage_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hat_entry_type\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x17\n\x0f\x63ontains_bbcode\x18\x04 \x01(\x08\x12\x16\n\x0e\x65\x63ho_to_sender\x18\x05 \x01(\x08\x12\x14\n\x0clow_priority\x18\x06 \x01(\x08\x12\x19\n\x11\x63lient_message_id\x18\x08 \x01(\t\"\x8c\x01\n$CFriendMessages_SendMessage_Response\x12\x18\n\x10modified_message\x18\x01 \x01(\t\x12\x18\n\x10server_timestamp\x18\x02 \x01(\r\x12\x0f\n\x07ordinal\x18\x03 \x01(\r\x12\x1f\n\x17message_without_bb_code\x18\x04 \x01(\t\"U\n\'CFriendMessages_AckMessage_Notification\x12\x17\n\x0fsteamid_partner\x18\x01 \x01(\x06\x12\x11\n\ttimestamp\x18\x02 \x01(\r\"<\n)CFriendMessages_IsInFriendsUIBeta_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\"e\n*CFriendMessages_IsInFriendsUIBeta_Response\x12\x1b\n\x13online_in_friendsui\x18\x01 \x01(\x08\x12\x1a\n\x12has_used_friendsui\x18\x02 \x01(\x08\"\xdb\x01\n-CFriendMessages_UpdateMessageReaction_Request\x12\x0f\n\x07steamid\x18\x01 \x01(\x06\x12\x18\n\x10server_timestamp\x18\x02 \x01(\r\x12\x0f\n\x07ordinal\x18\x03 \x01(\r\x12L\n\rreaction_type\x18\x04 \x01(\x0e\x32\x15.EMessageReactionType:\x1ek_EMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x05 \x01(\t\x12\x0e\n\x06is_add\x18\x06 \x01(\x08\"B\n.CFriendMessages_UpdateMessageReaction_Response\x12\x10\n\x08reactors\x18\x01 \x03(\r\"\x86\x02\n,CFriendMessages_IncomingMessage_Notification\x12\x16\n\x0esteamid_friend\x18\x01 \x01(\x06\x12\x17\n\x0f\x63hat_entry_type\x18\x02 \x01(\x05\x12\x1c\n\x14\x66rom_limited_account\x18\x03 \x01(\x08\x12\x0f\n\x07message\x18\x04 \x01(\t\x12 \n\x18rtime32_server_timestamp\x18\x05 \x01(\x07\x12\x0f\n\x07ordinal\x18\x06 \x01(\r\x12\x12\n\nlocal_echo\x18\x07 \x01(\x08\x12\x19\n\x11message_no_bbcode\x18\x08 \x01(\t\x12\x14\n\x0clow_priority\x18\t \x01(\x08\"\xf2\x01\n,CFriendMessages_MessageReaction_Notification\x12\x16\n\x0esteamid_friend\x18\x01 \x01(\x06\x12\x18\n\x10server_timestamp\x18\x02 \x01(\r\x12\x0f\n\x07ordinal\x18\x03 \x01(\r\x12\x0f\n\x07reactor\x18\x04 \x01(\x06\x12L\n\rreaction_type\x18\x05 \x01(\x0e\x32\x15.EMessageReactionType:\x1ek_EMessageReactionType_Invalid\x12\x10\n\x08reaction\x18\x06 \x01(\t\x12\x0e\n\x06is_add\x18\x07 \x01(\x08*\x83\x01\n\x14\x45MessageReactionType\x12\"\n\x1ek_EMessageReactionType_Invalid\x10\x00\x12#\n\x1fk_EMessageReactionType_Emoticon\x10\x01\x12\"\n\x1ek_EMessageReactionType_Sticker\x10\x02\x32\xbd\x08\n\x0e\x46riendMessages\x12\xa5\x01\n\x11GetRecentMessages\x12*.CFriendMessages_GetRecentMessages_Request\x1a+.CFriendMessages_GetRecentMessages_Response\"7\x82\xb5\x18\x33Get a log of recent chat messages between two users\x12\xc0\x01\n\x18GetActiveMessageSessions\x12\x32.CFriendsMessages_GetActiveMessageSessions_Request\x1a\x33.CFriendsMessages_GetActiveMessageSessions_Response\";\x82\xb5\x18\x37Get information about recent offline messages and chats\x12\x7f\n\x0bSendMessage\x12$.CFriendMessages_SendMessage_Request\x1a%.CFriendMessages_SendMessage_Response\"#\x82\xb5\x18\x1fSend a chat message to a friend\x12\x8c\x01\n\nAckMessage\x12(.CFriendMessages_AckMessage_Notification\x1a\x0b.NoResponse\"G\x82\xb5\x18\x43\x41\x63knowledge that we have seen the most recent message from a friend\x12\x9b\x01\n\x11IsInFriendsUIBeta\x12*.CFriendMessages_IsInFriendsUIBeta_Request\x1a+.CFriendMessages_IsInFriendsUIBeta_Response\"-\x82\xb5\x18)See if a friend is in the friendsui beta.\x12\xae\x01\n\x15UpdateMessageReaction\x12..CFriendMessages_UpdateMessageReaction_Request\x1a/.CFriendMessages_UpdateMessageReaction_Response\"4\x82\xb5\x18\x30\x41\x64\x64s/removes a reaction to/from a friend message\x1a\x61\x82\xb5\x18]A service for relaying and logging friend messages (user-to-user chats and offline messaging)2\x98\x03\n\x14\x46riendMessagesClient\x12r\n\x0fIncomingMessage\x12-.CFriendMessages_IncomingMessage_Notification\x1a\x0b.NoResponse\"#\x82\xb5\x18\x1fNew chat message from a friend.\x12\x8d\x01\n\x14NotifyAckMessageEcho\x12(.CFriendMessages_AckMessage_Notification\x1a\x0b.NoResponse\">\x82\xb5\x18:A session acked an unread message, echo to other sessions.\x12v\n\x0fMessageReaction\x12-.CFriendMessages_MessageReaction_Notification\x1a\x0b.NoResponse\"\'\x82\xb5\x18#New message reaction from a friend.\x1a\x04\xc0\xb5\x18\x02\x42\x03\x90\x01\x01'
  ,
  dependencies=[steammessages__base__pb2.DESCRIPTOR,steammessages__unified__base__pb2.DESCRIPTOR,])

_EMESSAGEREACTIONTYPE = _descriptor.EnumDescriptor(
  name='EMessageReactionType',
  full_name='EMessageReactionType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMessageReactionType_Invalid', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMessageReactionType_Emoticon', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='k_EMessageReactionType_Sticker', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3501,
  serialized_end=3632,
)
_sym_db.RegisterEnumDescriptor(_EMESSAGEREACTIONTYPE)

EMessageReactionType = enum_type_wrapper.EnumTypeWrapper(_EMESSAGEREACTIONTYPE)
k_EMessageReactionType_Invalid = 0
k_EMessageReactionType_Emoticon = 1
k_EMessageReactionType_Sticker = 2



_CFRIENDMESSAGES_GETRECENTMESSAGES_REQUEST = _descriptor.Descriptor(
  name='CFriendMessages_GetRecentMessages_Request',
  full_name='CFriendMessages_GetRecentMessages_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid1', full_name='CFriendMessages_GetRecentMessages_Request.steamid1', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steamid2', full_name='CFriendMessages_GetRecentMessages_Request.steamid2', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='CFriendMessages_GetRecentMessages_Request.count', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0309If non-zero, cap the number of recent messages to return.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='most_recent_conversation', full_name='CFriendMessages_GetRecentMessages_Request.most_recent_conversation', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030MGrab the block of chat from the most recent conversation (a ~5 minute period)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime32_start_time', full_name='CFriendMessages_GetRecentMessages_Request.rtime32_start_time', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030\207\001If non-zero, return only messages with timestamps greater or equal to this. If zero, we only return messages from a recent time cutoff.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bbcode_format', full_name='CFriendMessages_GetRecentMessages_Request.bbcode_format', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030*Return the results with bbcode formatting.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_ordinal', full_name='CFriendMessages_GetRecentMessages_Request.start_ordinal', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030iCombined with start time, only messages after this ordinal are returned (dedupes messages in same second)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_last', full_name='CFriendMessages_GetRecentMessages_Request.time_last', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\0306if present/non-zero, return only messages before this.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal_last', full_name='CFriendMessages_GetRecentMessages_Request.ordinal_last', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=852,
)


_CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE_MESSAGEREACTION = _descriptor.Descriptor(
  name='MessageReaction',
  full_name='CFriendMessages_GetRecentMessages_Response.FriendMessage.MessageReaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reaction_type', full_name='CFriendMessages_GetRecentMessages_Response.FriendMessage.MessageReaction.reaction_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction', full_name='CFriendMessages_GetRecentMessages_Response.FriendMessage.MessageReaction.reaction', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reactors', full_name='CFriendMessages_GetRecentMessages_Response.FriendMessage.MessageReaction.reactors', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1238,
  serialized_end=1369,
)

_CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE = _descriptor.Descriptor(
  name='FriendMessage',
  full_name='CFriendMessages_GetRecentMessages_Response.FriendMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid', full_name='CFriendMessages_GetRecentMessages_Response.FriendMessage.accountid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CFriendMessages_GetRecentMessages_Response.FriendMessage.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CFriendMessages_GetRecentMessages_Response.FriendMessage.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CFriendMessages_GetRecentMessages_Response.FriendMessage.ordinal', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reactions', full_name='CFriendMessages_GetRecentMessages_Response.FriendMessage.reactions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE_MESSAGEREACTION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1054,
  serialized_end=1369,
)

_CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE = _descriptor.Descriptor(
  name='CFriendMessages_GetRecentMessages_Response',
  full_name='CFriendMessages_GetRecentMessages_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='CFriendMessages_GetRecentMessages_Response.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030-Array of messages, returned newest to oldest.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='more_available', full_name='CFriendMessages_GetRecentMessages_Response.more_available', index=1,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=855,
  serialized_end=1369,
)


_CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_REQUEST = _descriptor.Descriptor(
  name='CFriendsMessages_GetActiveMessageSessions_Request',
  full_name='CFriendsMessages_GetActiveMessageSessions_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='lastmessage_since', full_name='CFriendsMessages_GetActiveMessageSessions_Request.lastmessage_since', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030`return only session information where a chat message has been sent since this time (for polling)', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='only_sessions_with_messages', full_name='CFriendsMessages_GetActiveMessageSessions_Request.only_sessions_with_messages', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030~If non-zero, return only message sessions that have messages since our message cutoff. If zero, we return all active sessions.', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1372,
  serialized_end=1723,
)


_CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE_FRIENDMESSAGESESSION = _descriptor.Descriptor(
  name='FriendMessageSession',
  full_name='CFriendsMessages_GetActiveMessageSessions_Response.FriendMessageSession',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accountid_friend', full_name='CFriendsMessages_GetActiveMessageSessions_Response.FriendMessageSession.accountid_friend', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_message', full_name='CFriendsMessages_GetActiveMessageSessions_Response.FriendMessageSession.last_message', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='last_view', full_name='CFriendsMessages_GetActiveMessageSessions_Response.FriendMessageSession.last_view', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unread_message_count', full_name='CFriendsMessages_GetActiveMessageSessions_Response.FriendMessageSession.unread_message_count', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1987,
  serialized_end=2106,
)

_CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE = _descriptor.Descriptor(
  name='CFriendsMessages_GetActiveMessageSessions_Response',
  full_name='CFriendsMessages_GetActiveMessageSessions_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='message_sessions', full_name='CFriendsMessages_GetActiveMessageSessions_Response.message_sessions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CFriendsMessages_GetActiveMessageSessions_Response.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\265\030RThis should be passed in the next request as lastmessage_since to poll for updates', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE_FRIENDMESSAGESESSION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1726,
  serialized_end=2106,
)


_CFRIENDMESSAGES_SENDMESSAGE_REQUEST = _descriptor.Descriptor(
  name='CFriendMessages_SendMessage_Request',
  full_name='CFriendMessages_SendMessage_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CFriendMessages_SendMessage_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_entry_type', full_name='CFriendMessages_SendMessage_Request.chat_entry_type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CFriendMessages_SendMessage_Request.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='contains_bbcode', full_name='CFriendMessages_SendMessage_Request.contains_bbcode', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='echo_to_sender', full_name='CFriendMessages_SendMessage_Request.echo_to_sender', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_priority', full_name='CFriendMessages_SendMessage_Request.low_priority', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_message_id', full_name='CFriendMessages_SendMessage_Request.client_message_id', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2109,
  serialized_end=2303,
)


_CFRIENDMESSAGES_SENDMESSAGE_RESPONSE = _descriptor.Descriptor(
  name='CFriendMessages_SendMessage_Response',
  full_name='CFriendMessages_SendMessage_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='modified_message', full_name='CFriendMessages_SendMessage_Response.modified_message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_timestamp', full_name='CFriendMessages_SendMessage_Response.server_timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CFriendMessages_SendMessage_Response.ordinal', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_without_bb_code', full_name='CFriendMessages_SendMessage_Response.message_without_bb_code', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2306,
  serialized_end=2446,
)


_CFRIENDMESSAGES_ACKMESSAGE_NOTIFICATION = _descriptor.Descriptor(
  name='CFriendMessages_AckMessage_Notification',
  full_name='CFriendMessages_AckMessage_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_partner', full_name='CFriendMessages_AckMessage_Notification.steamid_partner', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CFriendMessages_AckMessage_Notification.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2448,
  serialized_end=2533,
)


_CFRIENDMESSAGES_ISINFRIENDSUIBETA_REQUEST = _descriptor.Descriptor(
  name='CFriendMessages_IsInFriendsUIBeta_Request',
  full_name='CFriendMessages_IsInFriendsUIBeta_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CFriendMessages_IsInFriendsUIBeta_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2535,
  serialized_end=2595,
)


_CFRIENDMESSAGES_ISINFRIENDSUIBETA_RESPONSE = _descriptor.Descriptor(
  name='CFriendMessages_IsInFriendsUIBeta_Response',
  full_name='CFriendMessages_IsInFriendsUIBeta_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='online_in_friendsui', full_name='CFriendMessages_IsInFriendsUIBeta_Response.online_in_friendsui', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='has_used_friendsui', full_name='CFriendMessages_IsInFriendsUIBeta_Response.has_used_friendsui', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2597,
  serialized_end=2698,
)


_CFRIENDMESSAGES_UPDATEMESSAGEREACTION_REQUEST = _descriptor.Descriptor(
  name='CFriendMessages_UpdateMessageReaction_Request',
  full_name='CFriendMessages_UpdateMessageReaction_Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid', full_name='CFriendMessages_UpdateMessageReaction_Request.steamid', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_timestamp', full_name='CFriendMessages_UpdateMessageReaction_Request.server_timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CFriendMessages_UpdateMessageReaction_Request.ordinal', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction_type', full_name='CFriendMessages_UpdateMessageReaction_Request.reaction_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction', full_name='CFriendMessages_UpdateMessageReaction_Request.reaction', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_add', full_name='CFriendMessages_UpdateMessageReaction_Request.is_add', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2701,
  serialized_end=2920,
)


_CFRIENDMESSAGES_UPDATEMESSAGEREACTION_RESPONSE = _descriptor.Descriptor(
  name='CFriendMessages_UpdateMessageReaction_Response',
  full_name='CFriendMessages_UpdateMessageReaction_Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reactors', full_name='CFriendMessages_UpdateMessageReaction_Response.reactors', index=0,
      number=1, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2922,
  serialized_end=2988,
)


_CFRIENDMESSAGES_INCOMINGMESSAGE_NOTIFICATION = _descriptor.Descriptor(
  name='CFriendMessages_IncomingMessage_Notification',
  full_name='CFriendMessages_IncomingMessage_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_friend', full_name='CFriendMessages_IncomingMessage_Notification.steamid_friend', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chat_entry_type', full_name='CFriendMessages_IncomingMessage_Notification.chat_entry_type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_limited_account', full_name='CFriendMessages_IncomingMessage_Notification.from_limited_account', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='CFriendMessages_IncomingMessage_Notification.message', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtime32_server_timestamp', full_name='CFriendMessages_IncomingMessage_Notification.rtime32_server_timestamp', index=4,
      number=5, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CFriendMessages_IncomingMessage_Notification.ordinal', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_echo', full_name='CFriendMessages_IncomingMessage_Notification.local_echo', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_no_bbcode', full_name='CFriendMessages_IncomingMessage_Notification.message_no_bbcode', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='low_priority', full_name='CFriendMessages_IncomingMessage_Notification.low_priority', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2991,
  serialized_end=3253,
)


_CFRIENDMESSAGES_MESSAGEREACTION_NOTIFICATION = _descriptor.Descriptor(
  name='CFriendMessages_MessageReaction_Notification',
  full_name='CFriendMessages_MessageReaction_Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='steamid_friend', full_name='CFriendMessages_MessageReaction_Notification.steamid_friend', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server_timestamp', full_name='CFriendMessages_MessageReaction_Notification.server_timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ordinal', full_name='CFriendMessages_MessageReaction_Notification.ordinal', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reactor', full_name='CFriendMessages_MessageReaction_Notification.reactor', index=3,
      number=4, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction_type', full_name='CFriendMessages_MessageReaction_Notification.reaction_type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reaction', full_name='CFriendMessages_MessageReaction_Notification.reaction', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_add', full_name='CFriendMessages_MessageReaction_Notification.is_add', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3256,
  serialized_end=3498,
)

_CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE_MESSAGEREACTION.fields_by_name['reaction_type'].enum_type = _EMESSAGEREACTIONTYPE
_CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE_MESSAGEREACTION.containing_type = _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE
_CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE.fields_by_name['reactions'].message_type = _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE_MESSAGEREACTION
_CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE.containing_type = _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE
_CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE.fields_by_name['messages'].message_type = _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE
_CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE_FRIENDMESSAGESESSION.containing_type = _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE
_CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE.fields_by_name['message_sessions'].message_type = _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE_FRIENDMESSAGESESSION
_CFRIENDMESSAGES_UPDATEMESSAGEREACTION_REQUEST.fields_by_name['reaction_type'].enum_type = _EMESSAGEREACTIONTYPE
_CFRIENDMESSAGES_MESSAGEREACTION_NOTIFICATION.fields_by_name['reaction_type'].enum_type = _EMESSAGEREACTIONTYPE
DESCRIPTOR.message_types_by_name['CFriendMessages_GetRecentMessages_Request'] = _CFRIENDMESSAGES_GETRECENTMESSAGES_REQUEST
DESCRIPTOR.message_types_by_name['CFriendMessages_GetRecentMessages_Response'] = _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE
DESCRIPTOR.message_types_by_name['CFriendsMessages_GetActiveMessageSessions_Request'] = _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_REQUEST
DESCRIPTOR.message_types_by_name['CFriendsMessages_GetActiveMessageSessions_Response'] = _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE
DESCRIPTOR.message_types_by_name['CFriendMessages_SendMessage_Request'] = _CFRIENDMESSAGES_SENDMESSAGE_REQUEST
DESCRIPTOR.message_types_by_name['CFriendMessages_SendMessage_Response'] = _CFRIENDMESSAGES_SENDMESSAGE_RESPONSE
DESCRIPTOR.message_types_by_name['CFriendMessages_AckMessage_Notification'] = _CFRIENDMESSAGES_ACKMESSAGE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CFriendMessages_IsInFriendsUIBeta_Request'] = _CFRIENDMESSAGES_ISINFRIENDSUIBETA_REQUEST
DESCRIPTOR.message_types_by_name['CFriendMessages_IsInFriendsUIBeta_Response'] = _CFRIENDMESSAGES_ISINFRIENDSUIBETA_RESPONSE
DESCRIPTOR.message_types_by_name['CFriendMessages_UpdateMessageReaction_Request'] = _CFRIENDMESSAGES_UPDATEMESSAGEREACTION_REQUEST
DESCRIPTOR.message_types_by_name['CFriendMessages_UpdateMessageReaction_Response'] = _CFRIENDMESSAGES_UPDATEMESSAGEREACTION_RESPONSE
DESCRIPTOR.message_types_by_name['CFriendMessages_IncomingMessage_Notification'] = _CFRIENDMESSAGES_INCOMINGMESSAGE_NOTIFICATION
DESCRIPTOR.message_types_by_name['CFriendMessages_MessageReaction_Notification'] = _CFRIENDMESSAGES_MESSAGEREACTION_NOTIFICATION
DESCRIPTOR.enum_types_by_name['EMessageReactionType'] = _EMESSAGEREACTIONTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CFriendMessages_GetRecentMessages_Request = _reflection.GeneratedProtocolMessageType('CFriendMessages_GetRecentMessages_Request', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDMESSAGES_GETRECENTMESSAGES_REQUEST,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendMessages_GetRecentMessages_Request)
  })
_sym_db.RegisterMessage(CFriendMessages_GetRecentMessages_Request)

CFriendMessages_GetRecentMessages_Response = _reflection.GeneratedProtocolMessageType('CFriendMessages_GetRecentMessages_Response', (_message.Message,), {

  'FriendMessage' : _reflection.GeneratedProtocolMessageType('FriendMessage', (_message.Message,), {

    'MessageReaction' : _reflection.GeneratedProtocolMessageType('MessageReaction', (_message.Message,), {
      'DESCRIPTOR' : _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE_MESSAGEREACTION,
      '__module__' : 'steammessages_friendmessages_pb2'
      # @@protoc_insertion_point(class_scope:CFriendMessages_GetRecentMessages_Response.FriendMessage.MessageReaction)
      })
    ,
    'DESCRIPTOR' : _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE_FRIENDMESSAGE,
    '__module__' : 'steammessages_friendmessages_pb2'
    # @@protoc_insertion_point(class_scope:CFriendMessages_GetRecentMessages_Response.FriendMessage)
    })
  ,
  'DESCRIPTOR' : _CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendMessages_GetRecentMessages_Response)
  })
_sym_db.RegisterMessage(CFriendMessages_GetRecentMessages_Response)
_sym_db.RegisterMessage(CFriendMessages_GetRecentMessages_Response.FriendMessage)
_sym_db.RegisterMessage(CFriendMessages_GetRecentMessages_Response.FriendMessage.MessageReaction)

CFriendsMessages_GetActiveMessageSessions_Request = _reflection.GeneratedProtocolMessageType('CFriendsMessages_GetActiveMessageSessions_Request', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_REQUEST,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsMessages_GetActiveMessageSessions_Request)
  })
_sym_db.RegisterMessage(CFriendsMessages_GetActiveMessageSessions_Request)

CFriendsMessages_GetActiveMessageSessions_Response = _reflection.GeneratedProtocolMessageType('CFriendsMessages_GetActiveMessageSessions_Response', (_message.Message,), {

  'FriendMessageSession' : _reflection.GeneratedProtocolMessageType('FriendMessageSession', (_message.Message,), {
    'DESCRIPTOR' : _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE_FRIENDMESSAGESESSION,
    '__module__' : 'steammessages_friendmessages_pb2'
    # @@protoc_insertion_point(class_scope:CFriendsMessages_GetActiveMessageSessions_Response.FriendMessageSession)
    })
  ,
  'DESCRIPTOR' : _CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendsMessages_GetActiveMessageSessions_Response)
  })
_sym_db.RegisterMessage(CFriendsMessages_GetActiveMessageSessions_Response)
_sym_db.RegisterMessage(CFriendsMessages_GetActiveMessageSessions_Response.FriendMessageSession)

CFriendMessages_SendMessage_Request = _reflection.GeneratedProtocolMessageType('CFriendMessages_SendMessage_Request', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDMESSAGES_SENDMESSAGE_REQUEST,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendMessages_SendMessage_Request)
  })
_sym_db.RegisterMessage(CFriendMessages_SendMessage_Request)

CFriendMessages_SendMessage_Response = _reflection.GeneratedProtocolMessageType('CFriendMessages_SendMessage_Response', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDMESSAGES_SENDMESSAGE_RESPONSE,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendMessages_SendMessage_Response)
  })
_sym_db.RegisterMessage(CFriendMessages_SendMessage_Response)

CFriendMessages_AckMessage_Notification = _reflection.GeneratedProtocolMessageType('CFriendMessages_AckMessage_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDMESSAGES_ACKMESSAGE_NOTIFICATION,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendMessages_AckMessage_Notification)
  })
_sym_db.RegisterMessage(CFriendMessages_AckMessage_Notification)

CFriendMessages_IsInFriendsUIBeta_Request = _reflection.GeneratedProtocolMessageType('CFriendMessages_IsInFriendsUIBeta_Request', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDMESSAGES_ISINFRIENDSUIBETA_REQUEST,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendMessages_IsInFriendsUIBeta_Request)
  })
_sym_db.RegisterMessage(CFriendMessages_IsInFriendsUIBeta_Request)

CFriendMessages_IsInFriendsUIBeta_Response = _reflection.GeneratedProtocolMessageType('CFriendMessages_IsInFriendsUIBeta_Response', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDMESSAGES_ISINFRIENDSUIBETA_RESPONSE,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendMessages_IsInFriendsUIBeta_Response)
  })
_sym_db.RegisterMessage(CFriendMessages_IsInFriendsUIBeta_Response)

CFriendMessages_UpdateMessageReaction_Request = _reflection.GeneratedProtocolMessageType('CFriendMessages_UpdateMessageReaction_Request', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDMESSAGES_UPDATEMESSAGEREACTION_REQUEST,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendMessages_UpdateMessageReaction_Request)
  })
_sym_db.RegisterMessage(CFriendMessages_UpdateMessageReaction_Request)

CFriendMessages_UpdateMessageReaction_Response = _reflection.GeneratedProtocolMessageType('CFriendMessages_UpdateMessageReaction_Response', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDMESSAGES_UPDATEMESSAGEREACTION_RESPONSE,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendMessages_UpdateMessageReaction_Response)
  })
_sym_db.RegisterMessage(CFriendMessages_UpdateMessageReaction_Response)

CFriendMessages_IncomingMessage_Notification = _reflection.GeneratedProtocolMessageType('CFriendMessages_IncomingMessage_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDMESSAGES_INCOMINGMESSAGE_NOTIFICATION,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendMessages_IncomingMessage_Notification)
  })
_sym_db.RegisterMessage(CFriendMessages_IncomingMessage_Notification)

CFriendMessages_MessageReaction_Notification = _reflection.GeneratedProtocolMessageType('CFriendMessages_MessageReaction_Notification', (_message.Message,), {
  'DESCRIPTOR' : _CFRIENDMESSAGES_MESSAGEREACTION_NOTIFICATION,
  '__module__' : 'steammessages_friendmessages_pb2'
  # @@protoc_insertion_point(class_scope:CFriendMessages_MessageReaction_Notification)
  })
_sym_db.RegisterMessage(CFriendMessages_MessageReaction_Notification)


DESCRIPTOR._options = None
_CFRIENDMESSAGES_GETRECENTMESSAGES_REQUEST.fields_by_name['count']._options = None
_CFRIENDMESSAGES_GETRECENTMESSAGES_REQUEST.fields_by_name['most_recent_conversation']._options = None
_CFRIENDMESSAGES_GETRECENTMESSAGES_REQUEST.fields_by_name['rtime32_start_time']._options = None
_CFRIENDMESSAGES_GETRECENTMESSAGES_REQUEST.fields_by_name['bbcode_format']._options = None
_CFRIENDMESSAGES_GETRECENTMESSAGES_REQUEST.fields_by_name['start_ordinal']._options = None
_CFRIENDMESSAGES_GETRECENTMESSAGES_REQUEST.fields_by_name['time_last']._options = None
_CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE.fields_by_name['messages']._options = None
_CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_REQUEST.fields_by_name['lastmessage_since']._options = None
_CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_REQUEST.fields_by_name['only_sessions_with_messages']._options = None
_CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE.fields_by_name['timestamp']._options = None

_FRIENDMESSAGES = _descriptor.ServiceDescriptor(
  name='FriendMessages',
  full_name='FriendMessages',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\202\265\030]A service for relaying and logging friend messages (user-to-user chats and offline messaging)',
  create_key=_descriptor._internal_create_key,
  serialized_start=3635,
  serialized_end=4720,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetRecentMessages',
    full_name='FriendMessages.GetRecentMessages',
    index=0,
    containing_service=None,
    input_type=_CFRIENDMESSAGES_GETRECENTMESSAGES_REQUEST,
    output_type=_CFRIENDMESSAGES_GETRECENTMESSAGES_RESPONSE,
    serialized_options=b'\202\265\0303Get a log of recent chat messages between two users',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetActiveMessageSessions',
    full_name='FriendMessages.GetActiveMessageSessions',
    index=1,
    containing_service=None,
    input_type=_CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_REQUEST,
    output_type=_CFRIENDSMESSAGES_GETACTIVEMESSAGESESSIONS_RESPONSE,
    serialized_options=b'\202\265\0307Get information about recent offline messages and chats',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendMessage',
    full_name='FriendMessages.SendMessage',
    index=2,
    containing_service=None,
    input_type=_CFRIENDMESSAGES_SENDMESSAGE_REQUEST,
    output_type=_CFRIENDMESSAGES_SENDMESSAGE_RESPONSE,
    serialized_options=b'\202\265\030\037Send a chat message to a friend',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AckMessage',
    full_name='FriendMessages.AckMessage',
    index=3,
    containing_service=None,
    input_type=_CFRIENDMESSAGES_ACKMESSAGE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030CAcknowledge that we have seen the most recent message from a friend',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IsInFriendsUIBeta',
    full_name='FriendMessages.IsInFriendsUIBeta',
    index=4,
    containing_service=None,
    input_type=_CFRIENDMESSAGES_ISINFRIENDSUIBETA_REQUEST,
    output_type=_CFRIENDMESSAGES_ISINFRIENDSUIBETA_RESPONSE,
    serialized_options=b'\202\265\030)See if a friend is in the friendsui beta.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMessageReaction',
    full_name='FriendMessages.UpdateMessageReaction',
    index=5,
    containing_service=None,
    input_type=_CFRIENDMESSAGES_UPDATEMESSAGEREACTION_REQUEST,
    output_type=_CFRIENDMESSAGES_UPDATEMESSAGEREACTION_RESPONSE,
    serialized_options=b'\202\265\0300Adds/removes a reaction to/from a friend message',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FRIENDMESSAGES)

DESCRIPTOR.services_by_name['FriendMessages'] = _FRIENDMESSAGES


_FRIENDMESSAGESCLIENT = _descriptor.ServiceDescriptor(
  name='FriendMessagesClient',
  full_name='FriendMessagesClient',
  file=DESCRIPTOR,
  index=1,
  serialized_options=b'\300\265\030\002',
  create_key=_descriptor._internal_create_key,
  serialized_start=4723,
  serialized_end=5131,
  methods=[
  _descriptor.MethodDescriptor(
    name='IncomingMessage',
    full_name='FriendMessagesClient.IncomingMessage',
    index=0,
    containing_service=None,
    input_type=_CFRIENDMESSAGES_INCOMINGMESSAGE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030\037New chat message from a friend.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NotifyAckMessageEcho',
    full_name='FriendMessagesClient.NotifyAckMessageEcho',
    index=1,
    containing_service=None,
    input_type=_CFRIENDMESSAGES_ACKMESSAGE_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030:A session acked an unread message, echo to other sessions.',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MessageReaction',
    full_name='FriendMessagesClient.MessageReaction',
    index=2,
    containing_service=None,
    input_type=_CFRIENDMESSAGES_MESSAGEREACTION_NOTIFICATION,
    output_type=steammessages__unified__base__pb2._NORESPONSE,
    serialized_options=b'\202\265\030#New message reaction from a friend.',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_FRIENDMESSAGESCLIENT)

DESCRIPTOR.services_by_name['FriendMessagesClient'] = _FRIENDMESSAGESCLIENT

FriendMessages = service_reflection.GeneratedServiceType('FriendMessages', (_service.Service,), dict(
  DESCRIPTOR = _FRIENDMESSAGES,
  __module__ = 'steammessages_friendmessages_pb2'
  ))

FriendMessages_Stub = service_reflection.GeneratedServiceStubType('FriendMessages_Stub', (FriendMessages,), dict(
  DESCRIPTOR = _FRIENDMESSAGES,
  __module__ = 'steammessages_friendmessages_pb2'
  ))


FriendMessagesClient = service_reflection.GeneratedServiceType('FriendMessagesClient', (_service.Service,), dict(
  DESCRIPTOR = _FRIENDMESSAGESCLIENT,
  __module__ = 'steammessages_friendmessages_pb2'
  ))

FriendMessagesClient_Stub = service_reflection.GeneratedServiceStubType('FriendMessagesClient_Stub', (FriendMessagesClient,), dict(
  DESCRIPTOR = _FRIENDMESSAGESCLIENT,
  __module__ = 'steammessages_friendmessages_pb2'
  ))


# @@protoc_insertion_point(module_scope)



"""
Helper moduel for calling ``gevent`` monkey patch functions.
This only need to if want to make stdlib gevent cooperative.
The patches need to be applied before any other module imports.

See :mod:`gevent.monkey` for details

.. code:: python

    import steam.monkey
    steam.monkey.patch_minimal()

    import requests
    from steam.client import SteamClient, EMsg
"""

def patch_minimal():
    """
    This method needs to be called before any other imports

    It calls :meth:`gevent.monkey.patch_socket()` and :meth:`gevent.monkey.patch_ssl()`
    """
    import gevent.monkey
    gevent.monkey.patch_socket()
    gevent.monkey.patch_ssl()
    gevent.monkey.patch_dns()
